pub(super) struct ListRotationsInput {
pub spec_id: Option<i32>,
pub name: Option<String>,
pub limit: Option<i64>,
pub offset: Option<i64>,
}Expand description
Input for listing/searching public rotations.
Fields
spec_id: Option<i32>name: Option<String>limit: Option<i64>offset: Option<i64>Trait Implementations
Sourceimpl Debug for ListRotationsInput
impl Debug for ListRotationsInput
Sourceimpl Default for ListRotationsInput
impl Default for ListRotationsInput
Sourcefn default() -> ListRotationsInput
fn default() -> ListRotationsInput
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ListRotationsInput
impl<'de> Deserialize<'de> for ListRotationsInput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListRotationsInput
impl JsonSchema for ListRotationsInput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ListRotationsInput
impl RefUnwindSafe for ListRotationsInput
impl Send for ListRotationsInput
impl Sync for ListRotationsInput
impl Unpin for ListRotationsInput
impl UnsafeUnpin for ListRotationsInput
impl UnwindSafe for ListRotationsInput